Simple Hand tracking game that uses pre programmed pointing gestures to control a block in pygame :
To install :

https://pypi.org/project/gesture-hand-game/

**AI USED TO REORDER FOLDERS AND TROUBLESHOOT**